@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <algorithm>
 #include <string>
 // #ifdef _OPENMP
@@ -11,6 +12,9 @@
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
 #include "util.h"
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern "C" {
 
@@ -322,9 +326,9 @@ extern "C" {
 	  
 	  //invert C and log det cov
 	  detCand = 0;
-	  F77_NAME(dpotrf)(lower, &N, C, &N, &info); if(info != 0){error("c++ error: Cholesky failed in spGLM\n");}
+	  F77_NAME(dpotrf)(lower, &N, C, &N, &info FCONE); if(info != 0){error("c++ error: Cholesky failed in spGLM\n");}
 	  for(k = 0; k < N; k++) detCand += 2*log(C[k*N+k]);
-	  F77_NAME(dpotri)(lower, &N, C, &N, &info); if(info != 0){error("c++ error: Cholesky inverse failed in spGLM\n");}
+	  F77_NAME(dpotri)(lower, &N, C, &N, &info FCONE); if(info != 0){error("c++ error: Cholesky inverse failed in spGLM\n");}
 
 	  //Likelihood with Jacobian   
 	  logPostCand = 0.0;
@@ -345,8 +349,8 @@ extern "C" {
 	  for(k = 0; k < m; k++) logPostCand += (m-k)*log(A[k*m+k])+log(A[k*m+k]);
 	  
 	  //get S*K^-1, already have the chol of K (i.e., A)
-	  F77_NAME(dpotri)(lower, &m, A, &m, &info); if(info != 0){error("c++ error: dpotri failed\n");}
-	  F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m);
+	  F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+	  F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m FCONE FCONE);
 	  for(k = 0; k < m; k++){SKtrace += tmp_mm[k*m+k];}
 	  logPostCand += -0.5*(KIW_df+m+1)*logDetK - 0.5*SKtrace;
 	  
@@ -358,7 +362,7 @@ extern "C" {
 	    }
 	  }
 
-	  F77_NAME(dgemv)(ntran, &N, &P, &one, X, &N, beta, &incOne, &zero, tmp_N, &incOne);
+	  F77_NAME(dgemv)(ntran, &N, &P, &one, X, &N, beta, &incOne, &zero, tmp_N, &incOne FCONE);
 
 	  if(family == "binomial"){
 	    logPostCand += binomial_logpost(N, Y, tmp_N, w, weights);
@@ -369,7 +373,7 @@ extern "C" {
 	  }
 	  
 	  //(-1/2) * tmp_n` *  C^-1 * tmp_n
-	  F77_NAME(dsymv)(lower, &N, &one, C, &N, w, &incOne, &zero, tmp_N1, &incOne);
+	  F77_NAME(dsymv)(lower, &N, &one, C, &N, w, &incOne, &zero, tmp_N1, &incOne FCONE);
 	  logPostCand += -0.5*detCand-0.5*F77_NAME(ddot)(&N, w, &incOne, tmp_N1, &incOne);
 	  
 	  //
@@ -429,11 +433,11 @@ extern "C" {
 	
 	//invert C and log det cov
 	detCand = 0;
-	F77_NAME(dpotrf)(lower, &N, C, &N, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
+	F77_NAME(dpotrf)(lower, &N, C, &N, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
 	for(k = 0; k < N; k++) detCand += 2*log(C[k*N+k]);
-	F77_NAME(dpotri)(lower, &N, C, &N, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+	F77_NAME(dpotri)(lower, &N, C, &N, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 	
-	F77_NAME(dgemv)(ntran, &N, &P, &one, X, &N, beta, &incOne, &zero, tmp_N, &incOne);
+	F77_NAME(dgemv)(ntran, &N, &P, &one, X, &N, beta, &incOne, &zero, tmp_N, &incOne FCONE);
 	
 	for(j = 0; j < N; j++){
 	  
@@ -464,8 +468,8 @@ extern "C" {
 	  for(k = 0; k < m; k++) logPostCand += (m-k)*log(A[k*m+k])+log(A[k*m+k]);
 	  
 	  //get S*K^-1, already have the chol of K (i.e., A)
-	  F77_NAME(dpotri)(lower, &m, A, &m, &info); if(info != 0){error("c++ error: dpotri failed\n");}
-	  F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m);
+	  F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+	  F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m FCONE FCONE);
 	  for(k = 0; k < m; k++){SKtrace += tmp_mm[k*m+k];}
 	  logPostCand += -0.5*(KIW_df+m+1)*logDetK - 0.5*SKtrace;
 	  
@@ -486,7 +490,7 @@ extern "C" {
 	  }
 	  
 	  //(-1/2) * tmp_n` *  C^-1 * tmp_n
-	  F77_NAME(dsymv)(lower, &N, &one, C, &N, w, &incOne, &zero, tmp_N1, &incOne);
+	  F77_NAME(dsymv)(lower, &N, &one, C, &N, w, &incOne, &zero, tmp_N1, &incOne FCONE);
 	  logPostCand += -0.5*detCand-0.5*F77_NAME(ddot)(&N, w, &incOne, tmp_N1, &incOne);
 	  
 	  //
