@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <string>
 // #ifdef _OPENMP
 // #include <omp.h>
@@ -9,6 +10,9 @@
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
 #include "util.h"
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern "C" {
 
@@ -303,9 +307,9 @@ extern "C" {
 
       //invert C and log det cov
       detCand = 0;
-      F77_NAME(dpotrf)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
+      F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
       for(i = 0; i < nm; i++) detCand += 2*log(C[i*nm+i]);
-      F77_NAME(dpotri)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotri)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
       
       //Likelihood with Jacobian   
       logPostCand = 0.0;
@@ -326,8 +330,8 @@ extern "C" {
       for(i = 0; i < m; i++) logPostCand += (m-i)*log(A[i*m+i])+log(A[i*m+i]);
       
       //get S*K^-1, already have the chol of K (i.e., A)
-      F77_NAME(dpotri)(lower, &m, A, &m, &info); if(info != 0){error("c++ error: dpotri failed\n");}
-      F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m);
+      F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, KIW_S, &m, &zero, tmp_mm, &m FCONE FCONE);
       for(i = 0; i < m; i++){SKtrace += tmp_mm[i*m+i];}
       logPostCand += -0.5*(KIW_df+m+1)*logDetK - 0.5*SKtrace;
 
@@ -339,7 +343,7 @@ extern "C" {
 	}
       }
    
-      F77_NAME(dgemv)(ntran, &nm, &p, &one, X, &nm, beta, &incOne, &zero, tmp_nm, &incOne);
+      F77_NAME(dgemv)(ntran, &nm, &p, &one, X, &nm, beta, &incOne, &zero, tmp_nm, &incOne FCONE);
      
       if(family == "binomial"){
 	logPostCand += binomial_logpost(nm, Y, tmp_nm, wCand, weights);
@@ -350,7 +354,7 @@ extern "C" {
       }
 
       //(-1/2) * tmp_n` *  C^-1 * tmp_n
-      F77_NAME(dsymv)(lower, &nm, &one,  C, &nm, wCand, &incOne, &zero, tmp_nm, &incOne);
+      F77_NAME(dsymv)(lower, &nm, &one,  C, &nm, wCand, &incOne, &zero, tmp_nm, &incOne FCONE);
       logPostCand += -0.5*detCand-0.5*F77_NAME(ddot)(&nm, wCand, &incOne, tmp_nm, &incOne);
 
       //
