@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #ifdef _OPENMP
 #include <omp.h>
 #endif
@@ -12,6 +13,10 @@
 #include <R_ext/Linpack.h>
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
+#ifndef FCONE
+# define FCONE
+#endif
+
 
 extern "C" {
 
@@ -350,11 +355,11 @@ extern "C" {
       tmp_nn = (double *) R_alloc(nn, sizeof(double));
       Cbeta = (double *) R_alloc(nn, sizeof(double));
 
-      F77_NAME(dgemv)(ntran, &n, &p, &negOne, X, &n, betaMu, &incOne, &zero, z, &incOne);
+      F77_NAME(dgemv)(ntran, &n, &p, &negOne, X, &n, betaMu, &incOne, &zero, z, &incOne FCONE);
       F77_NAME(daxpy)(&n, &one, Y, &incOne, z, &incOne);
 
-      F77_NAME(dsymm)(rside, lower, &n, &p, &one, betaC, &p, X, &n, &zero, vU, &n);
-      F77_NAME(dgemm)(ntran, ytran, &n, &n, &p, &one, vU, &n, X, &n, &zero, tmp_nn, &n);
+      F77_NAME(dsymm)(rside, lower, &n, &p, &one, betaC, &p, X, &n, &zero, vU, &n FCONE FCONE);
+      F77_NAME(dgemm)(ntran, ytran, &n, &n, &p, &one, vU, &n, X, &n, &zero, tmp_nn, &n FCONE FCONE);
     }
     
     if(verbose){
@@ -458,29 +463,29 @@ extern "C" {
 	    }
 
 	    det = 0;
-	    F77_NAME(dpotrf)(lower, &n, Cbeta, &n, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dpotrf)(lower, &n, Cbeta, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
 	    for(k = 0; k < n; k++) det += log(Cbeta[k*n+k]);
 	    
 	    F77_NAME(dcopy)(&n, z, &incOne, tmp_n, &incOne);
-	    F77_NAME(dtrsv)(lower, ntran, nUnit, &n, Cbeta, &n, tmp_n, &incOne);//L[u] = (y-X'beta)
+	    F77_NAME(dtrsv)(lower, ntran, nUnit, &n, Cbeta, &n, tmp_n, &incOne FCONE FCONE FCONE);//L[u] = (y-X'beta)
 
 	    Q = pow(F77_NAME(dnrm2)(&n, tmp_n, &incOne),2);
 	  }else{//beta flat
 	    det = 0;
 
-	    F77_NAME(dpotrf)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotrf failed\n");}//L
+	    F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}//L
 	    for(k = 0; k < n; k++) det += log(C[k*n+k]);
 	    
 	    F77_NAME(dcopy)(&n, Y, &incOne, vU, &incOne);
 	    F77_NAME(dcopy)(&np, X, &incOne, &vU[n], &incOne);
-	    F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &n, &p1, &one, C, &n, vU, &n);//L[v:U] = [y:X]
+	    F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &n, &p1, &one, C, &n, vU, &n FCONE FCONE FCONE FCONE);//L[v:U] = [y:X]
 
-	    F77_NAME(dgemm)(ytran, ntran, &p, &p, &n, &one, &vU[n], &n, &vU[n], &n, &zero, tmp_pp, &p); //U'U
-	    F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
+	    F77_NAME(dgemm)(ytran, ntran, &p, &p, &n, &one, &vU[n], &n, &vU[n], &n, &zero, tmp_pp, &p FCONE FCONE); //U'U
+	    F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
 	    for(k = 0; k < p; k++) det += log(tmp_pp[k*p+k]);
 	    
-	    F77_NAME(dgemv)(ytran, &n, &p, &one, &vU[n], &n, vU, &incOne, &zero, tmp_p, &incOne); //U'v
-	    F77_NAME(dtrsv)(lower, ntran, nUnit, &p, tmp_pp, &p, tmp_p, &incOne);
+	    F77_NAME(dgemv)(ytran, &n, &p, &one, &vU[n], &n, vU, &incOne, &zero, tmp_p, &incOne FCONE); //U'v
+	    F77_NAME(dtrsv)(lower, ntran, nUnit, &p, tmp_pp, &p, tmp_p, &incOne FCONE FCONE FCONE);
 
 	    Q = pow(F77_NAME(dnrm2)(&n, vU, &incOne),2) - pow(F77_NAME(dnrm2)(&p, tmp_p, &incOne),2) ;
 	  }
@@ -501,8 +506,8 @@ extern "C" {
 	    for(k = 0; k < m; k++){logPostCand += (m-k)*log(A[k*m+k])+log(A[k*m+k]);}
 	    
 	    //S*K^-1
-	    F77_NAME(dpotri)(lower, &m, A, &m, &info); if(info != 0){error("c++ error: dpotri failed\n");}
-	    F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, Kb, &m, &zero, tmp_mm, &m);
+	    F77_NAME(dpotri)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+	    F77_NAME(dsymm)(rside, lower, &m, &m, &one, A, &m, Kb, &m, &zero, tmp_mm, &m FCONE FCONE);
 	    for(k = 0; k < m; k++){SKtrace += tmp_mm[k*m+k];}
 	    logPostCand += -0.5*(Ka[0]+m+1)*logDetK - 0.5*SKtrace;
 	    
